@@ -35,7 +35,7 @@ auto_fselector = function(
   store_benchmark_result = TRUE,
   store_models = FALSE,
   check_values = FALSE,
-  callbacks = list(),
+  callbacks = NULL,
   ties_method = "least_features"
   ) {
   terminator = terminator %??% terminator_selection(term_evals, term_time)
